;+
; NAME:
;	MEANFILTER
;
; PURPOSE:
;	This function process an array through a mean filter
;
; CATEGORY:
;	Pato's Numerical Utilities
;
; CALLING SEQUENCE:
;
;	smooth = MEANFILTER(Array, Radius)
;
; INPUTS:
;	Array:     A 2-dimensional array to be filtered
;       Radius:    Radius of mean filter
;
; OUTPUTS:
;	This function returns the mean filtered array
;
; RESTRICTIONS:
;
; PROCEDURE:
;	Applies mean filter by shifting and adding the ararys elements
;      in each dimension.
;
; EXAMPLE:
;	Mean filter a simple array to spreads its values
;
;               array  = [[0, 0, 0, 0, 0, 0, 0, 0], $
;                         [0, 0, 0, 0, 0, 0, 0, 0], $
;                         [0, 0, 1, 0, 0, 0, 0, 0], $
;                         [0, 0, 0, 0, 0, 0, 0, 0], $
;                         [0, 0, 0, 0, 0, 0, 0, 0], $
;                         [0, 0, 0, 0, 0, 1, 0, 0], $
;                         [0, 0, 0, 0, 0, 0, 0, 0], $
;                         [0, 0, 0, 0, 0, 0, 0, 0]]
;		smooth = MEANFILTER(array, 10)
;
; MODIFICATION HISTORY:
; 	Written by:	Pato Rojo, Cornell.  Aug 2005
;			pato@astro.cornell.edu
;-
function meanfilter, data, radius
;smooth

nx = (size(data, /dim))[0]
ny = (size(data, /dim))[1]

inx = indgen(nx)
iny = indgen(ny)

ac=dblarr(nx, ny)

retx  = dblarr(nx, ny)
ret   = retx
for i = -radius, radius do retx = retx + data[((inx+i) < (nx-1)) > 0,*]
for i = -radius, radius do ret  = ret  + retx[*,((iny+i) > 0) < (nx-1)]

ret /= float((radius*2+1) * (radius*2+1))

return, ret

end
